import { deviceFetch } from '../../../api/fetch';

// pages/components/EquipmentWarning/EquipmentWarning.js
Component({
  lifetimes: {
    attached() {
      if (!this.data.warningTypeRange) {
        this.fetchWarningLevelList();
      }
    },
  },
  /**
   * 组件的属性列表
   */
  properties: {
    areaId: {
      type: Number,
      value: 0,
      observer(newVal) {
        this.refreshList();
      },
    },
  },

  /**
   * 组件的初始数据
   */
  data: {
    warningLevelRange: [],
    warnLevelIndex: '',
    warnLevel: 0,
    deviceLocation: '',
    dataList: [],
    pageNum: 1,
    pageSize: 10,
  },

  /**
   * 组件的方法列表
   */
  methods: {
    fetchWarningLevelList() {
      deviceFetch({
        url: '/device/warning/dict/illegalOperations',
      })
        .then(res => {
          console.log(res);
          this.setData({
            warningLevelRange: res.data,
          });
        })
        .catch(err => {
          console.log(err);
        });
    },
    changeWarningType(e) {
      const index = e.detail.value;
      if (index === this.data.warnLevelIndex) return;
      const item = this.data.warningLevelRange[index];
      console.log(item);
      this.setData({
        warnLevelIndex: index,
        warnLevel: item.key,
      });
      this.refreshList();
    },
    changeLocation(e) {
      const { value } = e.detail;
      console.log(value);
      this.setData({
        deviceLocation: value,
      });
      this.refreshList();
    },
    fetchList(entity) {
      if (this.data.warnLevel) {
        entity.operation = this.data.warnLevel;
      }
      if (this.data.deviceLocation) {
        entity.deviceLocation = this.data.deviceLocation;
      }
      return deviceFetch({
        url: '/device/warning/paging',
        method: 'POST',
        data: {
          areaId: this.data.areaId,
          pageNum: this.data.pageNum,
          pageSize: this.data.pageSize,
          ...entity,
        },
      });
    },
    refreshList() {
      wx.showLoading({
        title: '加载中',
      });
      this.fetchList()
        .then(res => {
          wx.hideLoading();
          console.log(res);
          const { list } = res.data;
          if (list && list.length) {
            this.setData({
              dataList: list,
            });
          }
        })
        .catch(err => {
          wx.hideLoading();
          console.log(err);
        });
    },
    getMoreListItem() {
      wx.showLoading({
        title: '加载中',
      });
      let nextPage = this.data.pageNum + 1;
      this.fetchList({
        pageNum: nextPage,
      })
        .then(res => {
          wx.hideLoading();
          console.log(res);
          const { list, pageNum } = res.data;
          if (list && list.length) {
            this.setData({
              dataList: [...this.data.dataList, ...list],
              pageNum,
            });
          }
        })
        .catch(err => {
          wx.hideLoading();
          console.log(err);
        });
    },
    openEquipment(e) {
      const { code, type } = e.currentTarget.dataset;
      console.log(code);
      deviceFetch({
        url: `/device/${code}/${type}/enable`,
        method: 'POST',
      })
        .then(res => {
          wx.showToast({
            title: res.msg || '操作成功',
          });
          this.refreshList();
        })
        .catch(err => {
          console.log(err);
        });
    },
    closeEquipment(e) {
      const { code, type } = e.currentTarget.dataset;
      console.log(code);
      deviceFetch({
        url: `/device/${code}/${type}/forbidden`,
        method: 'POST',
      })
        .then(res => {
          wx.showToast({
            title: res.msg || '操作成功',
          });
          this.refreshList();
        })
        .catch(err => {
          console.log(err);
        });
    },
  },
});
